import defaultErrorHandler from './plugins/error_handler';
import defaultEventDispatcher from './plugins/event_dispatcher/index.browser';
import * as enums from './utils/enums';
import * as loggerPlugin from './plugins/logger';
import { OptimizelyDecideOption, Client, Config } from './shared_types';
/**
 * Creates an instance of the Optimizely class
 * @param  {Config} config
 * @return {Client|null} the Optimizely client object
 *                           null on error
 */
declare const createInstance: (config: Config) => Client | null;
declare const __internalResetRetryState: () => void;
/**
 * Entry point into the Optimizely Browser SDK
 */
declare const setLogHandler: typeof import("./modules/logging").setLogHandler;
declare const setLogLevel: typeof import("./modules/logging").setLogLevel;
export { loggerPlugin as logging, defaultErrorHandler as errorHandler, defaultEventDispatcher as eventDispatcher, enums, setLogHandler as setLogger, setLogLevel, createInstance, __internalResetRetryState, OptimizelyDecideOption, };
declare const _default: {
    logging: typeof loggerPlugin;
    errorHandler: {
        handleError: typeof import("./plugins/error_handler").handleError;
    };
    eventDispatcher: {
        dispatchEvent: (eventObj: import("./plugins/event_dispatcher/index.browser").Event, callback: (response: {
            statusCode: number;
        }) => void) => void;
    };
    enums: typeof enums;
    setLogger: typeof import("./modules/logging").setLogHandler;
    setLogLevel: typeof import("./modules/logging").setLogLevel;
    createInstance: (config: Config) => Client | null;
    __internalResetRetryState: () => void;
    OptimizelyDecideOption: typeof OptimizelyDecideOption;
};
export default _default;
export * from './export_types';
